@@ -240,8 +240,8 @@ def get_remote_file_hash(url, max_file_size=100 * 1024 * 1024):
 
 def image_extension(image_url):
     r = requests.head(image_url)
-    if (r.headers["content-type"]):
-        return r.headers["content-type"].split('/')[1]
+    if r.headers.get("content-type", None):
+        return r.headers.get("content-type", "").split('/')[1]
     else:
         return image_url.split('.')[-1]
 
@@ -279,8 +279,12 @@ def download_resized_image(url, filename):
         return filename
     except Exception as e:
         logger.error("Error when downloading/writing file %s error %s ..." % (filename, e))
-    url_extension = image_extension(url)
-    real_extension = imghdr.what(filename)
+    try:
+        url_extension = image_extension(url)
+        real_extension = imghdr.what(filename)
+    except Exception as e:
+        logger.info("Exception file %s " % e)
+        return None
     if real_extension != url_extension:
         file_hash = filename.split('.')[0]
         try:
