@@ -343,9 +343,13 @@ def get_details_trainings_for_client(customer_name, customer_type, project_name,
         date_end_training = ""
         url_training_file = ""
     else:
-        info_last_training = json.loads(response[0])['training'+ str(response[1])]
-        date_end_training = info_last_training['date_end_training']
-        url_training_file = info_last_training['url_training_file']
+        try:
+            info_last_training = json.loads(response[0])['training'+ str(response[1])]
+            date_end_training = info_last_training['date_end_training']
+            url_training_file = info_last_training['url_training_file']
+        except Exception as e:
+            date_end_training = ""
+            url_training_file = ""
 
     result={'url_training_file': url_training_file,
             'date_end_training': date_end_training,
