@@ -118,6 +118,7 @@ def delta_retrieve_json(customer_name, customer_type, project_name):
         last_json = {customer_name + "_" + customer_type: []}
         before_last_json = {customer_name + "_" + customer_type: []}
     try:
+        print("*** delta: comparing last json file: "+last_json_path+" with: "+before_last_json_path)
         difference = diff(before_last_json, last_json)
     except Exception as e:
         logger.error("Error_diff %s" %e)
@@ -269,42 +270,36 @@ def image_extension(image_url):
 
 
 def max_nb_images(path):
-    try:
-        list_nbrs = []
-        for j in os.listdir(path):
-            for k in os.listdir(str(path) + "/" + str(j)):
-                ext = imghdr.what(str(path) + "/" + str(j) + "/" + str(k))
-                if (ext == 'png' and k.split(".")[1] in ['jpg', 'jpeg', 'JPG', 'JPEG']) or \
-                        (ext in ['jpeg', 'jpg'] and k.split('.')[1] in ['png', 'PNG']) or (ext is None):
-                    os.remove(str(path) + "/" + str(j) + "/" + str(k))
-                    logger.info("Deleting_image as it contains png encoding - " + str(path) + "/" + str(j) + "/" + str(k))
-            list_nbrs.append(len(os.listdir(str(path) + "/" + str(j))))
-        return max(list_nbrs)
-    except Exception as e:
-        logger.error(e)
+    list_nbrs = []
+    for j in os.listdir(path):
+        for k in os.listdir(str(path) + "/" + str(j)):
+            ext = imghdr.what(str(path) + "/" + str(j) + "/" + str(k))
+            if (ext == 'png' and k.split(".")[1] in ['jpg', 'jpeg', 'JPG', 'JPEG']) or \
+                    (ext in ['jpeg', 'jpg'] and k.split('.')[1] in ['png', 'PNG']) or (ext is None):
+                os.remove(str(path) + "/" + str(j) + "/" + str(k))
+                logger.info("Deleting_image as it contains png encoding - " + str(path) + "/" + str(j) + "/" + str(k))
+        list_nbrs.append(len(os.listdir(str(path) + "/" + str(j))))
+    return max(list_nbrs)
+
 
 def verif_folder_less_twenty(path):
-    try:
-        image_ext = ['.jpg', '.png', '.jpeg', '.JPG', '.PNG', '.JPEG']
-        folder_less_20 = []
-        max_nb = max_nb_images(path)
-        if max_nb < 50:
-            max_nb = 50
-        #else max nb va prendre le max automatiquement
-        for j in os.listdir(path):
-            x = 0
-            for i in os.listdir(str(path) + "/" + str(j)):
-                if os.path.splitext(i)[1] in image_ext:
-                    x = x + 1
-            if x == 0 :
-                shutil.rmtree(str(path) + "/" + str(j))
-                logger.info("Deletin Empty folder : " + str(path) + "/" + str(j))
-            elif (x <= 50 or x < max_nb):
-                logger.info("WARNING: Folder has less images : " + str(j).split('/')[-1])
-                folder_less_20.append(str(j).split('/')[-1])
-        return folder_less_20, max_nb
-    except Exception as e:
-        logger.error(e)
+    image_ext = ['.jpg', '.png', '.jpeg', '.JPG', '.PNG', '.JPEG']
+    folder_less_20 = []
+    max_nb = max_nb_images(path)
+    if max_nb < 20:
+        max_nb = 20
+    for j in os.listdir(path):
+        x = 0
+        for i in os.listdir(str(path) + "/" + str(j)):
+            if os.path.splitext(i)[1] in image_ext:
+                x = x + 1
+        if x == 0 :
+            shutil.rmtree(str(path) + "/" + str(j))
+            logger.info("Deletin Empty folder : " + str(path) + "/" + str(j))
+        elif (x <= 20 or x < max_nb):
+            logger.info("WARNING: Folder has less images : " + str(j).split('/')[-1])
+            folder_less_20.append(str(j).split('/')[-1])
+    return folder_less_20, max_nb
 
 
 def generate_more_images(training_path, folders, max_nb):
